.. csv-table:: SBB scheme in table form
  :header: label, type, required, documentation, default, allowed_values, example
  :widths: 30, 8, 8, 50, 10, 30, 30

  "header:", "object", "-", "Contains licensing and usage information", "", "", ""
  "· description:", "str", "-", "Short info on the purpose of this scheme", "schema to describe a uPDK.", "", ""
  "· file_version:", "str", "-", "version of the SBB file", "1.0", "", ""
  "· openEPDA:", "object", "-", "openEPDA related information.", "", "", ""
  "· · version:", "str", "-", "openEPDA version of this scheme", "openEPDA-uPDK-SBB-v0.2", "", ""
  "· · link:", "str", "-", "Link to openEPDA site.", "https://www.openEPDA.org", "", ""
  "· schema_license:", "object", "-", "License information for using this superscheme and the derived scheme", "", "", ""
  "· · license:", "str", "-", "CC BY-ND 4.0 - Mandatory Creative Commons license condition", "CC BY-ND 4.0", "", ""
  "· · attribution:", "str", "-", "openEPDA--uPDK-SBB-v0.2, Ronald Broeke (c) 2017-2019 - Mandatory attribution required under the Creative Commons license", "openEPDA-uPDK-SBB-v0.2, Ronald Broeke (c) 2017-2019", "", ""
  "· pdk_license:", "str", "-", "License conditions of the content in the YAML.", "", "", "under NDA, Joe & sons #123-1999"
  "xsections:", "object", "", "Contains zero or more cross section definitions.", "", "", ""
  "· <xsection_name>:", "object", "", "Define a cross section reference named <xsection_name>.", "", "", ""
  "· · width:", "float", "", "Define the default width of a structure in this xsection <xsection_name>.", "", "", ""
  "· · width_min:", "float", "", "Define the minimum width of a structure in this xsection <xsection_name>.", "", "", ""
  "· · radius:", "float", "", "Define the default radius of a structure in this xsection <xsection_name>.", "", "", ""
  "· · radius_min:", "float", "", "Define the minimum radius of a structure in this xsection <xsection_name>.", "", "", ""
  "· · models:", "object", "", "Contains zero or more compact models for xsection <xsection_name>.", "", "", ""
  "· · · models:", "subschema", "", "models", "", "", ""
  "blocks:", "object", "-", "Contains zero or more BB definitions.", "", "", ""
  "· <block_name>:", "object", "", "Define a BB reference named <block_name>.", "", "", ""
  "· · id:", "str", "", "Reference to the unique ID used for this block across PDK version.", "None", "", ""
  "· · version:", "str", "", "BB version number set by the foundry.", "", "", ""
  "· · license:", "str", "-", "Licensing conditions of this BB.", "Block may be licensed.", "", "Licensed by foundry X under Y."
  "· · cellname:", "str", "", "Cellname of the BB. If no cellname label is found, the <block_name> is the cell name.", "", "", ""
  "· · doc:", "str", "-", "Short sentence to describe the BB to the user.", "", "", ""
  "· · bbox:", "list", "-", "Array of points (x, y) defining the bbox outline as a polygon. The polygon does not have to be closed.", "None", "", "[[0, 0], [10, 0], [10, 5], [0, 5]]"
  "· · bb_width:", "float", "", "Width of the BB cell in um.", "", "", ""
  "· · bb_length:", "float", "", "Length of the BB cell in um.", "", "", ""
  "· · pin_in:", "str", "", "Name of default input pin of the BB.", "", "", ""
  "· · pin_out:", "str", "", "Name of default output pin of the BB.", "", "", ""
  "· · pins:", "object", "-", "Contains one or more pin definitions for <block_name>.", "", "", ""
  "· · · <pin_name>:", "object", "-", "Define a pin named <pin_name>.", "", "", ""
  "· · · · id:", "int", "", "unique identifier", "", "", ""
  "· · · · width:", "float", "-", "Width of the pin.", "", "", "2.0"
  "· · · · width_unit:", "str", "", "Unit of the pin width.", "um", "list of allowed values", "um"
  "· · · · xsection:", "str", "-", "Cross section name.", "", "", "WAVEGUIDE"
  "· · · · alias:", "str", "", "Alias for <pin_name>.", "", "", "input1"
  "· · · · doc:", "str", "-", "Short description of the pin.", "", "", "optical input"
  "· · · · xya:", "list", "-", "Pin coordinate (x, y, a) with respect to <block_name> origin.", "", "", "[0, 0, 0]"
  "· · · · xya_unit:", "list", "", "Units of the (x, y, a) coordinate", "['um', 'um', 'deg']", "", ""
  "· · · · direction:", "str", "", "pin direction of xya w.r.t. the block; outward 'out' or inward 'in'.", "out", "['in', 'out']", ""
  "· · · · radius:", "float", "", "radius of curvature at pin (0 or null is no curvature).", "", "", ""
  "· · models:", "object", "", "Define zero or more compact models.", "None", "", ""
  "· · · models:", "subschema", "", "models", "", "", ""
  "· · drc:", "object", "-", "Define zero or more DRC rules.", "None", "", ""
  "· · · drc_rules:", "subschema", "", "drc rules", "", "", ""
  "· · parameters:", "object", "-", "Pcell only. Contains one or more BB parameter definitions.", "", "", ""
  "· · · <parameter_name>:", "object", "", "Define a BB parameter.", "", "", ""
  "· · · · doc:", "str", "-", "Short parameter description.", "No documentation provided", "", ""
  "· · · · type:", "str", "-", "Data type", "", "['float', 'int', 'str']", ""
  "· · · · unit:", "str", "-", "Unit of the parameter", "", "list of allowed values", "['um']"
  "· · · · min:", "see type", "-", "Minimum value.", "None", "", ""
  "· · · · max:", "see type", "-", "Maximum value.", "None", "", ""
  "· · · · value:", "see type", "-", "Default value.", "None", "list of allowed values if applicable", ""
  "· · · · alias:", "str", "", "Alias for <parameter_name>.", "", "", ""
  "· · keywordparameters:", "list", "", "List of <parameter_name> used in the BB function call (subset of parameters). If the label is not present, all parameters are considered to be keyword parameters.", "", "", "['a', 'b', 'c']"
  "· · cellnameparameters:", "list", "", "List of <parameter_name> for more descriptive cell names (subset of keywordparameters).", "", "", "b, x"
  "· · call:", "str", "", "name of function call that creates the BB", "", "", ""
  "· · groupname:", "str", "", "Name for grouping BB.", "", "", ""
  "· · ip_block:", "object", "", "Define ip_block data as ip_block", "", "", ""
  "· · · ip_block:", "subschema", "", "i- block information", "", "", ""
  "· · icon:", "object", "", "Define an icon for <block_name>.", "", "", ""
  "· · · function:", "str", "", "Name of the function that returns a cell with the icon.", "", "", ""
  "· · · parameters:", "object", "", "Parameters for which default will be overridden.", "", "", ""
  "· · · · bufx:", "float", "", "Buffer in the x-direction in um.", "", "", ""
  "· · · · bufy:", "float", "", "Buffer in the y-direction in um.", "", "", ""
  "· · · · length:", "float", "", "Icon length in the x-direction in um.", "", "", ""
  "· · · · width:", "float", "", "Icon length in the y-direction in um.", "", "", ""
  "subschemas:", "object", "", "Describe zero or more subschemas", "", "", ""
  "· drc-rules:", "object", "", "Describe one or more <<drc-rules>>", "", "", ""
  "· · angle:", "object", "", "angle DRC rule for instantiation w.r.t the mask", "", "", ""
  "· · · values_and_domains:", "subschema", "", "values and domains", "", "", ""
  "· · angle_mirror:", "object", "", "angle DRC rule for instantiation w.r.t the mask with mirroring status", "", "", ""
  "· · · flip:", "object", "", "group rules that apply for a flip=true state", "", "", ""
  "· · · · values_and_domains:", "subschema", "", "values and domains", "", "", ""
  "· · · noflip:", "object", "", "group rules that apply for a flip=false state", "", "", ""
  "· · · · values_and_domains:", "subschema", "", "values and domains", "", "", ""
  "· values_and_domains:", "object", "", "Describe one or more <<values_and_domains>>.", "", "", ""
  "· · values:", "list", "", "list of allowed angles", "", "", "[0, 90, 270]"
  "· · domains:", "list", "", "list of allowed angle domains", "", "", "[[0, 90], [180, 270]]"
  "· models:", "object", "", "Describe one or models.", "", "", ""
  "· · <model_name>:", "object", "", "Define a compact model reference named <model_name>.", "", "", "model_1"
  "· · · id:", "int", "", "compact model unique identifier.", "", "", ""
  "· · · name:", "str", "", "Reference to a compact model description.", "", "", ""
  "· · · parameters:", "object", "", "Contains one or more parameter assignments.", "", "", "{'a': 4.0, 'x': 10}"
  "· · · · <parameter_name>:", "str", "", "Assign a value to <parameter_name>.", "", "", ""
  "· ip_block:", "object", "", "Describe ip-block data.", "", "", ""
  "· · license:", "str", "", "License information", "", "", "CC BY-ND 4.0"
  "· · owner:", "str", "", "IP_Block owner", "", "", "Bright Photonics"
  "· · pgp_file:", "str", "", "Name of pgp encrypted ip_block file.", "", "", ""
  "· · pgp_key:", "str", "", "Hash of public pgp key used to encrypt the IP-Block.", "", "", ""
  "· · md5:", "str", "", "md5 hash of decrypted pgp ip_block.", "", "", ""
